@@ -15,18 +15,18 @@ public:
 
 private:
     void resizeEvent(QResizeEvent *event);
-    void addCharButtons(uint columns);
-    void removeCharButtons();
+    void addCharacters();
+    void removeCharacters();
 
 private slots:
     void on_actionAbout_triggered();
-    void buttonChar_clicked(uint id);
+    void on_chart_currentItemChanged(QListWidgetItem *item, QListWidgetItem *prev);
+    void on_chart_itemActivated(QListWidgetItem *item);
     void buttonCopy_clicked();
     void buttonClear_clicked();
 
 private:
     Ui::MainWindow ui;
-    int w;
     QLabel *labelCharacter;
     QLabel *labelUnicode;
     QLabel *labelDescription;
